@@ -1,6 +1,6 @@
 package HTML::Shakan::Renderer::HTML;
 use Any::Moose;
-use HTML::Entities 'encode_entities';
+use HTML::Shakan::Utils;
 
 has 'id_tmpl' => (
     is => 'ro',
@@ -11,19 +11,18 @@ has 'id_tmpl' => (
 sub render {
     my ($self, $form) = @_;
 
-    my $res = '';
-    for my $field (@{$form->fields}) {
+    my @res;
+    for my $field ($form->fields) {
         unless ($field->id) {
             $field->id(sprintf($self->id_tmpl(), $field->{name}));
         }
-        if ($field->{label}) {
-            $res .=
-                sprintf( q{<label for="%s">%s</label>},
+        if ($field->label) {
+            push @res, sprintf( q{<label for="%s">%s</label>},
                 $field->{id}, encode_entities( $field->{label} ) );
         }
-        $res .= $form->widgets->render( $form, $field );
+        push @res, $form->widgets->render( $form, $field );
     }
-    $res;
+    join '', @res;
 }
 
 no Any::Moose;
